json-logging
============

Python logging library to emit JSON log that can be easily indexed and
searchable by logging infrastructure such as
`ELK <https://www.elastic.co/webinars/introduction-elk-stack>`_.

Go here for full documentation: https://github.com/thangbn/json-logging-python